@@ -3,13 +3,18 @@ package Padre::Plugin::XML;
 use warnings;
 use strict;
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 use base 'Padre::Plugin';
 use Wx ':everything';
 
 sub padre_interfaces {
-	'Padre::Plugin' => '0.21',
+	'Padre::Plugin'   => 0.21,
+	'Padre::Document' => 0.21,
+}
+
+sub registered_documents {
+	'text/xml' => 'Padre::Document::XML',
 }
 
 sub menu_plugins_simple {
@@ -34,7 +39,7 @@ sub tidy_xml {
 	my $string = $tidy_obj->toString();
 	if ( $src ) {
 		my $editor = $self->selected_editor;
-	    $editor->ReplaceSelection( $string );
+		$editor->ReplaceSelection( $string );
 	} else {
 		$doc->text_set( $string );
 	}
